# ARCTK
Numerical simulations of physical systems - library and example binaries

[![ARCTK crate](https://img.shields.io/crates/v/arctk.svg)](https://crates.io/crates/arctk)
[![ARCTK documentation](https://docs.rs/arctk/badge.svg)](https://docs.rs/arctk)
![minimum rustc 1.47](https://img.shields.io/badge/rustc-1.47+-red.svg)
[![Build Status](https://travis-ci.org/FreddyWordingham/arctk.svg?branch=master)](https://travis-ci.org/FreddyWordingham/arctk)

Look in the /src/bin directory to see examples of ARCTK in use.

Or check out the standalone render engine:
[Antler render engine](https://github.com/FreddyWordingham/antler)
<!-- [Antler render engine](https://crates.io/crates/antler) -->
